@@ -23,6 +23,7 @@ _SET_SYSTEM_MODE_PATH = "api/setsystemmode"
 _SET_MINOR_MODE_PATH = "api/setminormode"
 _SYNC_SCHEDULE_PATH = "api/syncschedule"
 _SWITCH_SCHEDULE_PATH = "api/switchschedule"
+_SET_HOT_WATER_TEMPERATURE_PATH = "api/sethotwatertemperature"
 _VAILLANT_DEVICE_TYPE = "NAVaillant"
 _VAILLANT_DATA_AMOUNT = "app"
 _VAILLANT_SYNC_DEVICE_ID = "all"
@@ -267,6 +268,32 @@ class ThermostatClient(BaseClient):
         if body["status"] != _RESPONSE_STATUS_OK:
             raise NonOkResponseException("Unknown response error. Check the log for more details.", path=path, data=data, body=body)
 
+    async def async_set_hot_water_temperature(
+        self,
+        device_id: str,
+        dhw: int,
+    ) -> None:
+        """
+        Update boilers's domestic hot water temperature to the provided value. Value should be in valid range which can be retrieved
+        by calling /api/getthermostatsdata.
+
+        On success, returns nothing. On error, throws an exception.
+        """
+
+        path = _SET_HOT_WATER_TEMPERATURE_PATH
+        data = {
+            "device_id": device_id,
+            "dhw": dhw,
+        }
+
+        body = await self._post(
+            path,
+            data=data,
+        )
+
+        if body["status"] != _RESPONSE_STATUS_OK:
+            raise NonOkResponseException("Unknown response error. Check the log for more details.", path=path, data=data, body=body)
+
     def _get_setpoint_endtime(
         self,
         setpoint_mode: SetpointMode,
@@ -373,6 +400,7 @@ class Module:
         setpoint_manual: dict = {},
         therm_program_list: list[dict] = [],
         measured: dict = {},
+        boiler_status: bool = False,
         **kwargs,
     ) -> None:
         """Create new module model."""
@@ -385,8 +413,10 @@ class Module:
         self.battery_percent = battery_percent
         self.setpoint_away = Setpoint(**setpoint_away)
         self.setpoint_manual = Setpoint(**setpoint_manual)
-        self.therm_program_list = [Program(**program) for program in therm_program_list]
+        self.therm_program_list = [
+            Program(**program) for program in therm_program_list]
         self.measured = Measured(**measured)
+        self.boiler_status = boiler_status
 
     def __eq__(self, other: Module):
         if not isinstance(other, Module):
@@ -561,7 +591,10 @@ class OutdoorTemperature:
         """Create new measured attribute."""
 
         self.te = te
-        self.ti = datetime.fromtimestamp(ti)
+        if ti is None:
+            self.ti = None
+        else:
+            self.ti = datetime.fromtimestamp(ti)
 
 
 class Measured:
@@ -633,10 +666,21 @@ class MeasurementType(Enum):
     SUM_BOILER_ON = "sum_boiler_on"
     SUM_BOILER_OFF = "sum_boiler_off"
 
+    SUM_ENERGY_GAS_HEATING = "sum_energy_gaz_heating"
+    SUM_ENERGY_GAS_WATER = "sum_energy_gaz_hot_water"
+    SUM_ENERGY_ELEC_HEATING = "sum_energy_elec_heating"
+    SUM_ENERGY_ELEC_WATER = "sum_energy_elec_hot_water"
+
 
 class MeasurementScale(Enum):
     """MeasurementScale enumeration representing possible scale options for measurements of the thermostat."""
 
     MAX = "max"
+    FIVE_MINS = "5min"
     HALF_HOUR = "30min"
     HOUR = "1hour"
+    THREE_HOURS = "3hours"
+    SIX_HOURS = "6hours"
+    DAY = "1day"
+    WEEK = "1week"
+    MONTH = "1month"
